diff --git a/VERSION_NUMBER b/VERSION_NUMBER
index 141f2e805b..15b989e398 100644
--- a/VERSION_NUMBER
+++ b/VERSION_NUMBER
@@ -1 +1 @@
-1.15.0
+1.16.0
diff --git a/csharp/src/Microsoft.ML.OnnxRuntime/Training/NativeTrainingMethods.shared.cs b/csharp/src/Microsoft.ML.OnnxRuntime/Training/NativeTrainingMethods.shared.cs
index 35c44c44a0..260817f712 100644
--- a/csharp/src/Microsoft.ML.OnnxRuntime/Training/NativeTrainingMethods.shared.cs
+++ b/csharp/src/Microsoft.ML.OnnxRuntime/Training/NativeTrainingMethods.shared.cs
@@ -60,10 +60,10 @@ namespace Microsoft.ML.OnnxRuntime
DOrtGetApi OrtGetApi = (DOrtGetApi)Marshal.GetDelegateForFunctionPointer(NativeMethods.OrtGetApiBase().GetApi, typeof(DOrtGetApi));
// TODO: Make this save the pointer, and not copy the whole structure across
- api_ = (OrtApi)OrtGetApi(13 /*ORT_API_VERSION*/);
+ api_ = (OrtApi)OrtGetApi(16 /*ORT_API_VERSION*/);
OrtGetTrainingApi = (DOrtGetTrainingApi)Marshal.GetDelegateForFunctionPointer(api_.GetTrainingApi, typeof(DOrtGetTrainingApi));
- trainingApiPtr = OrtGetTrainingApi(13 /*ORT_API_VERSION*/);
+ trainingApiPtr = OrtGetTrainingApi(16 /*ORT_API_VERSION*/);
if (trainingApiPtr != IntPtr.Zero)
{
trainingApi_ = (OrtTrainingApi)Marshal.PtrToStructure(trainingApiPtr, typeof(OrtTrainingApi));
diff --git a/docs/python/README.rst b/docs/python/README.rst
index f5f162b1d4..7d978b0941 100644
--- a/docs/python/README.rst
+++ b/docs/python/README.rst
@@ -8,6 +8,11 @@ For more information on ONNX Runtime, please see `aka.ms/onnxruntime `_
or the `Github project `_.
"""
-__version__ = "1.15.0"
+__version__ = "1.16.0"
__author__ = "Microsoft"
# we need to do device version validation (for example to check Cuda version for an onnxruntime-training package).
diff --git a/package/rpm/onnxruntime.spec b/package/rpm/onnxruntime.spec
deleted file mode 100644
index d4efef8900..0000000000
--- a/package/rpm/onnxruntime.spec
+++ /dev/null
@@ -1,63 +0,0 @@
-Name: onnxruntime
-Version: 1.15.0
-Release: 1%{?dist}
-Summary: onnxruntime
-
-License: MIT
-URL: https://onnx.ai
-Source0: onnxruntime.tar
-
-BuildRequires: gcc
-BuildRequires: gcc-c++
-BuildRequires: zlib-devel
-BuildRequires: make
-BuildRequires: git
-BuildRequires: python3-devel
-BuildRequires: python3-numpy
-BuildRequires: python3-setuptools
-BuildRequires: python3-wheel
-BuildRequires: bzip2
-Requires: libstdc++
-Requires: glibc
-
-%description
-
-
-%prep
-%autosetup
-
-
-%build
-mkdir debug
-cd debug
-/opt/cmake/bin/cmake -Donnxruntime_DEV_MODE=OFF -DCMAKE_DEBUG_POSTFIX=_debug -DCMAKE_BUILD_TYPE=Debug -Deigen_SOURCE_PATH=/usr/include/eigen3 -Donnxruntime_USE_PREINSTALLED_EIGEN=ON -Donnxruntime_BUILD_SHARED_LIB=ON -DCMAKE_INSTALL_PREFIX=%{_prefix} ../cmake
-%make_build
-cd ..
-mkdir release
-cd release
-/opt/cmake/bin/cmake -Donnxruntime_DEV_MODE=OFF -DCMAKE_BUILD_TYPE=RelWithDebInfo -Deigen_SOURCE_PATH=/usr/include/eigen3 -Donnxruntime_USE_PREINSTALLED_EIGEN=ON -Donnxruntime_BUILD_SHARED_LIB=ON -DCMAKE_INSTALL_PREFIX=%{_prefix} ../cmake
-%make_build
-cd ..
-
-%install
-rm -rf $RPM_BUILD_ROOT
-cd debug
-%make_install
-cd ..
-cd release
-%make_install
-cd ..
-
-%files
-%license LICENSE
-%doc docs/*
-%doc ThirdPartyNotices.txt
-%{_bindir}/onnx_test_runner
-%{_libdir}/libonnxruntime.so*
-%{_libdir}/libonnxruntime_debug.so*
-%{_includedir}/onnxruntime/*
-
-
-%changelog
-* Wed Oct 17 2018 ONNXRuntime Team
-- Initial release
diff --git a/tools/python/update_version.py b/tools/python/update_version.py
index 415f83b043..187a6c47e3 100755
--- a/tools/python/update_version.py
+++ b/tools/python/update_version.py
@@ -64,22 +64,6 @@ def update_version():
f.write(line)
lines = []
current_version = ""
- file_path = os.path.join(cwd, "..", "..", "package", "rpm", "onnxruntime.spec")
- with open(file_path) as f:
- lines = f.readlines()
- for line in lines:
- if line.startswith("Version:"):
- current_version = line.split(":")[1].strip()
- break
- if version != current_version:
- with open(file_path, "w") as f:
- for line in lines:
- if line.startswith("Version:"):
- f.write("Version: " + version + "\n")
- continue
- f.write(line)
- lines = []
- current_version = ""
file_path = os.path.join(cwd, "..", "..", "onnxruntime", "__init__.py")
with open(file_path) as f:
lines = f.readlines()
diff --git a/onnxruntime/core/session/onnxruntime_c_api.cc b/onnxruntime/core/session/onnxruntime_c_api.cc
index d27bdf05a0..a3fcaceffc 100644
--- a/onnxruntime/core/session/onnxruntime_c_api.cc
+++ b/onnxruntime/core/session/onnxruntime_c_api.cc
@@ -2423,7 +2423,7 @@ Second example, if we wanted to add and remove some members, we'd do this:
In GetApi we now make it return ort_api_3 for version 3.
*/
-static constexpr OrtApi ort_api_1_to_15 = {
+static constexpr OrtApi ort_api_1_to_16 = {
// NOTE: The ordering of these fields MUST not change after that version has shipped since existing binaries depend on this ordering.
// Shipped as version 1 - DO NOT MODIFY (see above text for more information)
@@ -2727,6 +2727,7 @@ static constexpr OrtApi ort_api_1_to_15 = {
&OrtApis::GetOptionalContainedTypeInfo,
&OrtApis::GetResizedStringTensorElementBuffer,
&OrtApis::KernelContext_GetAllocator};
+// End of Version 15 - DO NOT MODIFY ABOVE (see above text for more information)
// Asserts to do a some checks to ensure older Versions of the OrtApi never change (will detect an addition or deletion but not if they cancel out each other)
// If any of these asserts hit, read the above 'Rules on how to add a new Ort API version'
@@ -2745,18 +2746,20 @@ static_assert(offsetof(OrtApi, SynchronizeBoundOutputs) / sizeof(void*) == 203,
static_assert(offsetof(OrtApi, SessionOptionsAppendExecutionProvider_MIGraphX) / sizeof(void*) == 209, "Size of version 11 API cannot change");
static_assert(offsetof(OrtApi, ReleaseKernelInfo) / sizeof(void*) == 218, "Size of version 12 API cannot change");
static_assert(offsetof(OrtApi, ReleaseCANNProviderOptions) / sizeof(void*) == 224, "Size of version 13 API cannot change");
+static_assert(offsetof(OrtApi, GetSessionConfigEntry) / sizeof(void*) == 238, "Size of version 14 API cannot change");
+static_assert(offsetof(OrtApi, KernelContext_GetAllocator) / sizeof(void*) == 253, "Size of version 15 API cannot change");
// So that nobody forgets to finish an API version, this check will serve as a reminder:
-static_assert(std::string_view(ORT_VERSION) == "1.15.0",
+static_assert(std::string_view(ORT_VERSION) == "1.16.0",
"ORT_Version change detected, please follow below steps to ensure OrtApi is updated properly");
// 1. Update the hardcoded version string in above static_assert to silence it
// 2. If there were any APIs added to ort_api_1_to_15 above:
// a. Add the 'End of version #' markers (pattern above should be obvious)
// b. Add a static_assert in the directly above list of version sizes to ensure nobody adds any more functions to the just shipped API version
ORT_API(const OrtApi*, OrtApis::GetApi, uint32_t version) {
if (version >= 1 && version <= ORT_API_VERSION)
- return &ort_api_1_to_15;
+ return &ort_api_1_to_16;
fprintf(stderr, "The given version [%u] is not supported, only version 1 to %u is supported in this build.\n",
version, ORT_API_VERSION);
@@ -2745,18 +2746,20 @@ static_assert(offsetof(OrtApi, SynchronizeBoundOutputs) / sizeof(void*) == 203,
"ORT_Version change detected, please follow below steps to ensure OrtApi is updated properly");
// 1. Update the hardcoded version string in above static_assert to silence it
-// 2. If there were any APIs added to ort_api_1_to_15 above:
+// 2. If there were any APIs added to ort_api_1_to_16 above:
// a. Add the 'End of version #' markers (pattern above should be obvious)
// b. Add a static_assert in the directly above list of version sizes to ensure nobody adds any more functions to the just shipped API version